==> react-valid-props-1.0.0.tgz: package/src/react-valid-props.js <==


// https://facebook.github.io/react/docs/tags-and-attributes.html#svg-attributes
export const SVGPropNames = [
	'clipPath',
	'cx',
	'cy',
	'd',
	'dx',
	'dy',
	'fill',
	'fillOpacity',
	'fontFamily',
	'fontSize',
	'fx',
	'fy',
	'gradientTransform',
	'gradientUnits',
	'markerEnd',
	'markerMid',
	'markerStart',
	'offset',
	'opacity',
	'patternContentUnits',
	'patternUnits',
	'points',
	'preserveAspectRatio',
	'r',
	'rx',
	'ry',
	'spreadMethod',
	'stopColor',
	'stopOpacity',
	'stroke',
	'strokeDasharray',
	'strokeLinecap',
	'strokeOpacity',
	'strokeWidth',
	'textAnchor',
	'transform',
	'version',
	'viewBox',
	'x1',
	'x2',
	'x',
	'y1',
	'y2',
	'y'
]


export const HTMLPropNames = [
	'accept',
	'acceptCharset',
	'accessKey',
	'action',
	'allowFullScreen',
	'allowTransparency',
	'alt',
	'async',
	'autoComplete',
	'autoFocus',
	'autoPlay',
	'cellPadding',
	'cellSpacing',
	'charSet',
	'checked',
	'classID',
	'className',
	'colSpan',
	'cols',
	'content',
	'contentEditable',
	'contextMenu',
	'controls',
	'coords',
	'crossOrigin',
	'data',
	'dateTime',
	'defer',
	'dir',
	'disabled',
	'download',
	'draggable',
	'encType',
	'form',
	'formAction',
	'formEncType',
	'formMethod',
	'formNoValidate',
	'formTarget',
	'frameBorder',
	'headers',
	'height',
	'hidden',
	'high',
	'href',
	'hrefLang',
	'htmlFor',
	'httpEquiv',
	'icon',
	'id',
	'label',
	'lang',
	'list',
	'loop',
	'low',
	'manifest',
	'marginHeight',
	'marginWidth',
	'max',
	'maxLength',
	'media',
	'mediaGroup',
	'method',
	'min',
	'multiple',
	'muted',
	'name',
	'noValidate',
	'open',
	'optimum',
	'pattern',
	'placeholder',
	'poster',
	'preload',
	'radioGroup',
	'readOnly',
	'rel',
	'required',
	'role',
	'rowSpan',
	'rows',
	'sandbox',
	'scope',
	'scoped',
	'scrolling',
	'seamless',
	'selected',
	'shape',
	'size',
	'sizes',
	'span',
	'spellCheck',
	'src',
	'srcDoc',
	'srcSet',
	'start',
	'step',
	'style',
	'tabIndex',
	'target',
	'title',
	'type',
	'useMap',
	'value',
	'width',
	'wmode'
]

const toLower = (str) => !str ? null : propName.toLowerCase()


const mergedProps = SVGPropNames.concat(HTMLPropNames).map(propName => toLower(propName))

export const AllReactProps = mergedProps
	.filter((propName,index) => mergedProps.indexOf(propName) === index)


export function filterProps(props) {
	return Object.keys(props)
		.filter(propName => propName && AllReactProps.indexOf(toLower(propName)) > -1)
		.reduce((filteredProps,propName) => {
			filteredProps[propName] = props[propName]
			return filteredProps
		},{})
}

export default filterProps;

==> react-valid-props-1.0.1.tgz: package/src/react-valid-props.js <==


// https://facebook.github.io/react/docs/tags-and-attributes.html#svg-attributes
export const SVGPropNames = [
	'clipPath',
	'cx',
	'cy',
	'd',
	'dx',
	'dy',
	'fill',
	'fillOpacity',
	'fontFamily',
	'fontSize',
	'fx',
	'fy',
	'gradientTransform',
	'gradientUnits',
	'markerEnd',
	'markerMid',
	'markerStart',
	'offset',
	'opacity',
	'patternContentUnits',
	'patternUnits',
	'points',
	'preserveAspectRatio',
	'r',
	'rx',
	'ry',
	'spreadMethod',
	'stopColor',
	'stopOpacity',
	'stroke',
	'strokeDasharray',
	'strokeLinecap',
	'strokeOpacity',
	'strokeWidth',
	'textAnchor',
	'transform',
	'version',
	'viewBox',
	'x1',
	'x2',
	'x',
	'y1',
	'y2',
	'y'
]


export const HTMLPropNames = [
	'accept',
	'acceptCharset',
	'accessKey',
	'action',
	'allowFullScreen',
	'allowTransparency',
	'alt',
	'async',
	'autoComplete',
	'autoFocus',
	'autoPlay',
	'cellPadding',
	'cellSpacing',
	'charSet',
	'checked',
	'classID',
	'className',
	'colSpan',
	'cols',
	'content',
	'contentEditable',
	'contextMenu',
	'controls',
	'coords',
	'crossOrigin',
	'data',
	'dateTime',
	'defer',
	'dir',
	'disabled',
	'download',
	'draggable',
	'encType',
	'form',
	'formAction',
	'formEncType',
	'formMethod',
	'formNoValidate',
	'formTarget',
	'frameBorder',
	'headers',
	'height',
	'hidden',
	'high',
	'href',
	'hrefLang',
	'htmlFor',
	'httpEquiv',
	'icon',
	'id',
	'label',
	'lang',
	'list',
	'loop',
	'low',
	'manifest',
	'marginHeight',
	'marginWidth',
	'max',
	'maxLength',
	'media',
	'mediaGroup',
	'method',
	'min',
	'multiple',
	'muted',
	'name',
	'noValidate',
	'open',
	'optimum',
	'pattern',
	'placeholder',
	'poster',
	'preload',
	'radioGroup',
	'readOnly',
	'rel',
	'required',
	'role',
	'rowSpan',
	'rows',
	'sandbox',
	'scope',
	'scoped',
	'scrolling',
	'seamless',
	'selected',
	'shape',
	'size',
	'sizes',
	'span',
	'spellCheck',
	'src',
	'srcDoc',
	'srcSet',
	'start',
	'step',
	'style',
	'tabIndex',
	'target',
	'title',
	'type',
	'useMap',
	'value',
	'width',
	'wmode'
]

const toLower = (str) => !str ? null : str.toLowerCase()


const mergedProps = SVGPropNames.concat(HTMLPropNames).map(propName => toLower(propName))

export const AllReactProps = mergedProps
	.filter((propName,index) => mergedProps.indexOf(propName) === index)


export function filterProps(props) {
	return Object.keys(props)
		.filter(propName => propName && AllReactProps.indexOf(toLower(propName)) > -1)
		.reduce((filteredProps,propName) => {
			filteredProps[propName] = props[propName]
			return filteredProps
		},{})
}

export default filterProps;
